package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.HelpInitiateRecord;
import com.huiju.estateagents.service.IHelpInitiateRecordService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 助力活动发起人员记录  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-10-17
 */
@RestController
@RequestMapping("/")
public class HelpInitiateRecordController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(HelpInitiateRecordController.class);

    @Autowired
    public IHelpInitiateRecordService taHelpInitiateRecordService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/helpInitiateRecord",method= RequestMethod.GET)
    public ResponseBean helpInitiateRecordList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                               @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<HelpInitiateRecord> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<HelpInitiateRecord> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<HelpInitiateRecord> result = taHelpInitiateRecordService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("helpInitiateRecordList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param helpInitiateRecord 实体对象
     * @return
     */
    @RequestMapping(value="/helpInitiateRecord",method= RequestMethod.POST)
    public ResponseBean helpInitiateRecordAdd(@RequestBody HelpInitiateRecord helpInitiateRecord){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (taHelpInitiateRecordService.save(helpInitiateRecord)){
                responseBean.addSuccess(helpInitiateRecord);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("helpInitiateRecordAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/helpInitiateRecord/{id}", method= RequestMethod.DELETE)
    public ResponseBean helpInitiateRecordDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(taHelpInitiateRecordService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("helpInitiateRecordDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param helpInitiateRecord 实体对象
     * @return
     */
    @RequestMapping(value="/helpInitiateRecord/{id}",method= RequestMethod.PUT)
    public ResponseBean helpInitiateRecordUpdate(@PathVariable Integer id,
                                        @RequestBody HelpInitiateRecord helpInitiateRecord){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (taHelpInitiateRecordService.updateById(helpInitiateRecord)){
                responseBean.addSuccess(helpInitiateRecord);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("helpInitiateRecordUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/helpInitiateRecord/{id}",method= RequestMethod.GET)
    public ResponseBean helpInitiateRecordGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(taHelpInitiateRecordService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("helpInitiateRecordDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
