package com.huiju.estateagents.drainage.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.drainage.entity.TaDrainage;
import com.huiju.estateagents.drainage.service.ITaDrainageService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
    * 引流项目  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-10-18
 */
@RestController
@RequestMapping("/api")
public class TaDrainageController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaDrainageController.class);

    @Autowired
    public ITaDrainageService iTaDrainageService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taDrainage",method= RequestMethod.GET)
    public ResponseBean taDrainageList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                       @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaDrainage> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaDrainage> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("org_id",getOrgId(request));
            queryWrapper.orderByDesc("create_date");

            IPage<TaDrainage> result = iTaDrainageService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taDrainageList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taDrainage 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taDrainage/add",method= RequestMethod.POST)
    public ResponseBean taDrainageAdd(@RequestBody TaDrainage taDrainage,HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            taDrainage.setOrgId(getOrgId(request));
            if (iTaDrainageService.save(taDrainage)){
                responseBean.addSuccess(taDrainage);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taDrainageAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/admin/taDrainage/{id}", method= RequestMethod.DELETE)
    public ResponseBean taDrainageDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaDrainageService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taDrainageDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taDrainage 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taDrainage/{id}",method= RequestMethod.PUT)
    public ResponseBean taDrainageUpdate(@PathVariable Integer id,
                                        @RequestBody TaDrainage taDrainage){
        ResponseBean responseBean = new ResponseBean();
        try {
            taDrainage.setDrainageId(id);
            if (iTaDrainageService.updateById(taDrainage)){
                responseBean.addSuccess(taDrainage);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taDrainageUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taDrainage/{id}",method= RequestMethod.GET)
    public ResponseBean taDrainageGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaDrainageService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taDrainageDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
