package com.huiju.estateagents.drainage.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.StringUtils;
import com.huiju.estateagents.drainage.entity.TaDrainageRecord;
import com.huiju.estateagents.drainage.service.ITaDrainageRecordService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
    * 引流记录表 全网引流记录表 前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-10-18
 */
@RestController
@RequestMapping("/api")
public class TaDrainageRecordController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaDrainageRecordController.class);

    @Autowired
    public ITaDrainageRecordService iTaDrainageRecordService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taDrainageRecord",method= RequestMethod.GET)
    public ResponseBean taDrainageRecordList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                             @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                             @RequestParam(value = "drainageId") Integer drainageId,
                                             @RequestParam(value = "startTime") String startTime,
                                             @RequestParam(value = "endTime") String endTime,
                                             HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaDrainageRecord> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaDrainageRecord> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("drainage_id",drainageId);
            queryWrapper.eq("org_id",getOrgId(request));
            queryWrapper.gt(!StringUtils.isEmpty(startTime),"create_date",startTime);
            queryWrapper.lt(!StringUtils.isEmpty(endTime),"create_date",endTime);
            queryWrapper.orderByDesc("create_date");

            IPage<TaDrainageRecord> result = iTaDrainageRecordService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taDrainageRecordList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taDrainageRecord 实体对象
     * @return
     */
    @RequestMapping(value="/taDrainageRecord",method= RequestMethod.POST)
    public ResponseBean taDrainageRecordAdd(@RequestBody TaDrainageRecord taDrainageRecord){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaDrainageRecordService.save(taDrainageRecord)){
                responseBean.addSuccess(taDrainageRecord);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taDrainageRecordAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taDrainageRecord/{id}", method= RequestMethod.DELETE)
    public ResponseBean taDrainageRecordDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaDrainageRecordService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taDrainageRecordDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taDrainageRecord 实体对象
     * @return
     */
    @RequestMapping(value="/taDrainageRecord/{id}",method= RequestMethod.PUT)
    public ResponseBean taDrainageRecordUpdate(@PathVariable Integer id,
                                        @RequestBody TaDrainageRecord taDrainageRecord){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaDrainageRecordService.updateById(taDrainageRecord)){
                responseBean.addSuccess(taDrainageRecord);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taDrainageRecordUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taDrainageRecord/{id}",method= RequestMethod.GET)
    public ResponseBean taDrainageRecordGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaDrainageRecordService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taDrainageRecordDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
